==> camitk_4.1.2.orig.tar.gz: CamiTK-4.1.2/modeling/libraries/mml/monitoring/OrMultipleCriterion.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2018 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
// Stopping criteria includes
#include "OrMultipleCriterion.h"

// -------------------- constructor --------------------
OrMultipleCriterion::OrMultipleCriterion(mml::MultipleCriteria* m, MonitoringManager* monitoringManager, MultipleCriterion* parent): MultipleCriterion(m, monitoringManager, parent) {}

// -------------------- checkCriteria --------------------
bool OrMultipleCriterion::checkCriterion() {
    bool result = false;
    std::vector<StoppingCriterion*>::iterator it;
    for (it = criterias.begin(); it != criterias.end(); it++) {
        result = result || ((*it)->checkCriterion());
    }
    return result;
}

// -------------------- getName --------------------
std::string OrMultipleCriterion::getName() {
    return "Or";
}

==> camitk_5.0.2.orig.tar.gz: CamiTK-5.0.2/modeling/libraries/mml/monitoring/OrMultipleCriterion.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
// Stopping criteria includes
#include "OrMultipleCriterion.h"

// -------------------- constructor --------------------
OrMultipleCriterion::OrMultipleCriterion(mml::MultipleCriteria* m, MonitoringManager* monitoringManager, MultipleCriterion* parent): MultipleCriterion(m, monitoringManager, parent) {}

// -------------------- checkCriteria --------------------
bool OrMultipleCriterion::checkCriterion() {
    bool result = false;
    std::vector<StoppingCriterion*>::iterator it;
    for (it = criterias.begin(); it != criterias.end(); ++it) {
        result = result || ((*it)->checkCriterion());
    }
    return result;
}

// -------------------- getName --------------------
std::string OrMultipleCriterion::getName() {
    return "Or";
}
